@@ -33,15 +33,6 @@ mod bybit_inverse_future {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook_topk() {
-        gen_test_code!(
-            BybitInverseFutureWSClient,
-            subscribe_orderbook_topk,
-            &vec!["BTCUSDZ21".to_string()]
-        );
-    }
-
     #[test]
     fn subscribe_orderbook() {
         gen_test_code!(
@@ -105,15 +96,6 @@ mod bybit_inverse_swap {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook_topk() {
-        gen_test_code!(
-            BybitInverseSwapWSClient,
-            subscribe_orderbook_topk,
-            &vec!["BTCUSD".to_string()]
-        );
-    }
-
     #[test]
     fn subscribe_orderbook() {
         gen_test_code!(
@@ -159,15 +141,6 @@ mod bybit_linear_swap {
         );
     }
 
-    #[test]
-    fn subscribe_orderbook_topk() {
-        gen_test_code!(
-            BybitLinearSwapWSClient,
-            subscribe_orderbook_topk,
-            &vec!["BTCUSDT".to_string()]
-        );
-    }
-
     #[test]
     fn subscribe_orderbook() {
         gen_test_code!(
